==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TimeChaosFluentImpl<A extends TimeChaosFluent<A>> extends BaseFluent<A> implements TimeChaosFluent<A>{
  public TimeChaosFluentImpl() {
  }
  public TimeChaosFluentImpl(TimeChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TimeChaosSpecBuilder spec;
  private TimeChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TimeChaosFluent.MetadataNested<A> withNewMetadata() {
    return new TimeChaosFluentImpl.MetadataNestedImpl();
  }
  public TimeChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TimeChaosFluentImpl.MetadataNestedImpl(item);
  }
  public TimeChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TimeChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TimeChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TimeChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TimeChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TimeChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TimeChaosFluent.SpecNested<A> withNewSpec() {
    return new TimeChaosFluentImpl.SpecNestedImpl();
  }
  public TimeChaosFluent.SpecNested<A> withNewSpecLike(TimeChaosSpec item) {
    return new TimeChaosFluentImpl.SpecNestedImpl(item);
  }
  public TimeChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TimeChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TimeChaosSpecBuilder().build());
  }
  public TimeChaosFluent.SpecNested<A> editOrNewSpecLike(TimeChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TimeChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TimeChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TimeChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TimeChaosFluent.StatusNested<A> withNewStatus() {
    return new TimeChaosFluentImpl.StatusNestedImpl();
  }
  public TimeChaosFluent.StatusNested<A> withNewStatusLike(TimeChaosStatus item) {
    return new TimeChaosFluentImpl.StatusNestedImpl(item);
  }
  public TimeChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TimeChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TimeChaosStatusBuilder().build());
  }
  public TimeChaosFluent.StatusNested<A> editOrNewStatusLike(TimeChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TimeChaosFluentImpl that = (TimeChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TimeChaosFluent.MetadataNested<N>> implements TimeChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TimeChaosSpecFluentImpl<TimeChaosFluent.SpecNested<N>> implements TimeChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TimeChaosSpec item) {
      this.builder = new TimeChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TimeChaosSpecBuilder(this);
    }
    TimeChaosSpecBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TimeChaosStatusFluentImpl<TimeChaosFluent.StatusNested<N>> implements TimeChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TimeChaosStatus item) {
      this.builder = new TimeChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TimeChaosStatusBuilder(this);
    }
    TimeChaosStatusBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TimeChaosFluentImpl<A extends TimeChaosFluent<A>> extends BaseFluent<A> implements TimeChaosFluent<A>{
  public TimeChaosFluentImpl() {
  }
  public TimeChaosFluentImpl(TimeChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TimeChaosSpecBuilder spec;
  private TimeChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TimeChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new TimeChaosFluentImpl.MetadataNestedImpl();
  }
  public TimeChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TimeChaosFluentImpl.MetadataNestedImpl(item);
  }
  public TimeChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TimeChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TimeChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TimeChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TimeChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TimeChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TimeChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new TimeChaosFluentImpl.SpecNestedImpl();
  }
  public TimeChaosFluentImpl.SpecNested<A> withNewSpecLike(TimeChaosSpec item) {
    return new TimeChaosFluentImpl.SpecNestedImpl(item);
  }
  public TimeChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TimeChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TimeChaosSpecBuilder().build());
  }
  public TimeChaosFluentImpl.SpecNested<A> editOrNewSpecLike(TimeChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TimeChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TimeChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TimeChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TimeChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new TimeChaosFluentImpl.StatusNestedImpl();
  }
  public TimeChaosFluentImpl.StatusNested<A> withNewStatusLike(TimeChaosStatus item) {
    return new TimeChaosFluentImpl.StatusNestedImpl(item);
  }
  public TimeChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TimeChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TimeChaosStatusBuilder().build());
  }
  public TimeChaosFluentImpl.StatusNested<A> editOrNewStatusLike(TimeChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimeChaosFluentImpl that = (TimeChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TimeChaosFluentImpl.MetadataNested<N>> implements TimeChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TimeChaosSpecFluentImpl<TimeChaosFluentImpl.SpecNested<N>> implements TimeChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TimeChaosSpec item) {
      this.builder = new TimeChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TimeChaosSpecBuilder(this);
    }
    TimeChaosSpecBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TimeChaosStatusFluentImpl<TimeChaosFluentImpl.StatusNested<N>> implements TimeChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TimeChaosStatus item) {
      this.builder = new TimeChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TimeChaosStatusBuilder(this);
    }
    TimeChaosStatusBuilder builder;
    public N and() {
      return (N) TimeChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
